@@ -248,11 +248,11 @@ class Number(ConfigType):
 
     """Number class, base for Integer and Float.
 
+    :param num_type: the type of number used for casting (i.e int, float)
+    :param type_name: Type name to be used in the sample config file.
     :param min: Optional check that value is greater than or equal to min.
     :param max: Optional check that value is less than or equal to max.
-    :param type_name: Type name to be used in the sample config file.
     :param choices: Optional sequence of valid values.
-    :param num_type: the type of number used for casting (i.e int, float)
 
     .. versionadded:: 3.14
     """
@@ -358,9 +358,9 @@ class Float(Number):
 
     """Float type.
 
-    :param type_name: Type name to be used in the sample config file.
     :param min: Optional check that value is greater than or equal to min.
     :param max: Optional check that value is less than or equal to max.
+    :param type_name: Type name to be used in the sample config file.
 
     .. versionchanged:: 2.7
 
@@ -382,10 +382,10 @@ class Port(Integer):
 
     Represents a L4 Port.
 
-    :param type_name: Type name to be used in the sample config file.
-    :param choices: Optional sequence of valid values.
     :param min: Optional check that value is greater than or equal to min.
     :param max: Optional check that value is less than or equal to max.
+    :param type_name: Type name to be used in the sample config file.
+    :param choices: Optional sequence of valid values.
 
     .. versionadded:: 3.16
     """
@@ -397,10 +397,10 @@ class Port(Integer):
         min = self.PORT_MIN if min is None else min
         max = self.PORT_MAX if max is None else max
         if min < self.PORT_MIN:
-            raise ValueError('Min value cannot be less than %(min)d',
+            raise ValueError('Min value cannot be less than %(min)d' %
                              {'min': self.PORT_MIN})
         if max > self.PORT_MAX:
-            raise ValueError('Max value cannot be more than %(max)d',
+            raise ValueError('Max value cannot be more than %(max)d' %
                              {'max': self.PORT_MAX})
 
         super(Port, self).__init__(min=min, max=max, type_name=type_name,
@@ -441,7 +441,7 @@ class List(ConfigType):
 
     def __call__(self, value):
         if isinstance(value, (list, tuple)):
-            return list(value)
+            return list(six.moves.map(self.item_type, value))
 
         s = value.strip()
         if self.bounds:
@@ -769,9 +769,8 @@ class HostAddress(object):
     matching the opt values to the respective types as per RFC1912.
 
     :param version: defines which version should be explicitly
-    checked (4 or 6) in case of an IP address
+                    checked (4 or 6) in case of an IP address
     :param type_name: Type name to be used in the sample config file.
-
     """
 
     def __init__(self, version=None, type_name='host address value'):
@@ -796,7 +795,7 @@ class HostAddress(object):
             try:
                 value = self.hostname(value)
             except ValueError:
-                raise ValueError("%s is not a valid host address", value)
+                raise ValueError("%s is not a valid host address" % (value,))
         return value
 
     def __repr__(self):
